@@ -11,6 +11,7 @@ register_report(
         tag          => 'apclients',
         label        => 'Access Point Client Count',
         provides_csv => 1,
+        api_endpoint => 1,
     }
 );
 
@@ -37,14 +38,12 @@ get '/ajax/content/report/apclients' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/report/apclients.tt', { results => $json },
-            { layout => undef };
+        template 'ajax/report/apclients.tt', { results => $json };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/apclients_csv.tt',
-            { results => \@results },
-            { layout  => undef };
+            { results => \@results };
     }
 };
 
